Caterva2 documentation
======================

On demand access to remote Blosc2 data repositories.


.. grid:: 2

  .. grid-item-card::
    :img-top: _static/index_getting_started.svg

    Getting Started
    ^^^^^^^^^^^^^^^

    New to Caterva2? Check out the getting started guides. They contain an
    introduction to Caterva2 main concepts.

    +++

    .. button-ref:: getting_started/index
      :expand:
      :color: dark
      :click-parent:

      To the getting started guide

  .. grid-item-card::
    :img-top: _static/index_user_guide.svg

    Tutorials
    ^^^^^^^^^

    Step-by-step guides to deploying Caterva2, using it and developing your own clients.

    +++

    .. button-ref:: tutorials/index
      :expand:
      :color: dark
      :click-parent:

      To tutorials

  .. grid-item-card::
    :img-top: _static/index_api.svg

    API Reference
    ^^^^^^^^^^^^^

    The reference guide contains a detailed description of the Caterva2 API.

    +++

    .. button-ref:: reference/index
      :expand:
      :color: dark
      :click-parent:

      To the API reference

  .. grid-item-card::
    :img-top: _static/index_contribute.svg

    Development
    ^^^^^^^^^^^

    Saw a typo in the documentation? Want to improve
    existing functionalities? The contributing guidelines will guide
    you through the process of improving Caterva2.

    +++

    .. button-ref:: development/index
      :expand:
      :color: dark
      :click-parent:

      To the contributor's guide

..  toctree::
    :maxdepth: 1
    :hidden:

    Getting Started <getting_started/index>
    Tutorials <tutorials/index>
    API Reference <reference/index>
    Utilities <utilities/index>
    Development <development/index>
    Release Notes <release_notes/index>
